@@ -23,11 +23,18 @@ from slashed.completers import (
     PathCompleter,
 )
 from slashed.exceptions import CommandError, ExitCommandError
-from slashed.output import DefaultOutputWriter
+from slashed.output import (
+    DefaultOutputWriter,
+    QueueOutputWriter,
+    CallbackOutputWriter,
+    TransformOutputWriter,
+    SignalingOutputWriter,
+)
 from slashed.store import CommandStore
+from slashed.registry import CommandRegistry
 
 
-__version__ = "0.7.0"
+__version__ = "0.9.2"
 
 __all__ = [  # noqa: RUF022
     # Core
@@ -41,6 +48,11 @@ __all__ = [  # noqa: RUF022
     "ParsedCommandArgs",
     "SlashedCommand",
     "parse_command",
+    "CommandRegistry",
+    "CallbackOutputWriter",
+    "QueueOutputWriter",
+    "TransformOutputWriter",
+    "SignalingOutputWriter",
     # Completion
     "CompletionContext",
     "CompletionItem",
