@@ -49,3 +49,17 @@ def get_metadata(path: Path) -> str:
         return f"{path.suffix[1:].upper()} file, {size}"
     except Exception:  # noqa: BLE001
         return ""
+
+
+def get_first_line(text: str | None) -> str | None:
+    """Get first line of text, stripped of whitespace.
+
+    Args:
+        text: Input text or None
+
+    Returns:
+        First line without whitespace if text is provided, None otherwise
+    """
+    if not text:
+        return None
+    return text.split("\n")[0].strip()
